@@ -5,7 +5,6 @@ import copy
 
 # noinspection PyUnresolvedReferences
 import apscheduler
-import typing
 
 from function_scheduling_distributed_framework.set_frame_config import patch_frame_config, show_frame_config
 
@@ -17,6 +16,7 @@ from function_scheduling_distributed_framework.factories.publisher_factotry impo
 from function_scheduling_distributed_framework.factories.consumer_factory import get_consumer
 # noinspection PyUnresolvedReferences
 from function_scheduling_distributed_framework.utils import nb_print, patch_print, LogManager, LoggerMixin
+from function_scheduling_distributed_framework.timing_job import fsdf_background_scheduler,timing_publish_deco
 
 
 class BrokerEnum:
@@ -54,6 +54,7 @@ def task_deco(queue_name, *, function_timeout=0, threads_num=50,
               concurrent_num=50, specify_threadpool=None, concurrent_mode=1,
               max_retry_times=3, log_level=10, is_print_detail_exception=True, msg_schedule_time_intercal=0.0,
               qps: float = 0, msg_expire_senconds=0, is_using_distributed_frequency_control=False,
+              is_send_consumer_hearbeat_to_redis=False,
               logger_prefix='', create_logger_file=True, do_task_filtering=False, task_filtering_expire_seconds=0,
               is_consuming_function_use_multi_params=True,
               is_do_not_run_by_specify_time_effect=False, do_not_run_by_specify_time=('10:00:00', '22:00:00'),
@@ -90,19 +91,22 @@ def task_deco(queue_name, *, function_timeout=0, threads_num=50,
     def f(a, b):
         print(a + b)
 
-    consumer = get_consumer('queue_test_f01', consuming_function=f,qps=0.2, broker_kind=2) # 需要手动指定consuming_function入参的值。
+    consumer = get_consumer('queue_test_f01', consuming_function=f,qps=0.2, broker_kind=2)
+    # 需要手动指定consuming_function入参的值。
     for i in range(10, 20):
         consumer.publisher_of_same_queue.publish(dict(a=i, b=i * 2))
     consumer.start_consuming_message()
     '''
 
-    装饰器版本的 task_deco 入参 和 get_consumer 入参99%一致，唯一不同的是 装饰器版本加在了函数上自动知道消费函数了，所以不需要传consuming_function参数。
+    装饰器版本的 task_deco 入参 和 get_consumer 入参99%一致，唯一不同的是 装饰器版本加在了函数上自动知道消费函数了，
+    所以不需要传consuming_function参数。
     """
     # 装饰器版本能够自动知道消费函数，防止task_deco按照get_consumer的入参重复传参了consuming_function。
     consumer_init_kwargs = copy.copy(locals())
 
     def _deco(func):
         consumer = get_consumer(consuming_function=func, **consumer_init_kwargs)
+        func.is_decorated_as_consume_function = True
         func.consumer = consumer
         # 下面这些连等主要是由于元编程造成的不能再ide下智能补全，参数太长很难手动拼写出来
         func.start_consuming_message = func.consume = func.start = consumer.start_consuming_message
@@ -155,6 +159,8 @@ class IdeAutoCompleteHelper(LoggerMixin):
            IdeAutoCompleteHelper(f).start_consuming_message()  # 和 f.consume()等效
 
         """
+        self.is_decorated_as_consume_function = consuming_func_decorated.is_decorated_as_consume_function
+
         self.consuming_func_decorated = consuming_func_decorated
 
         self.consumer = consuming_func_decorated.consumer  # type: AbstractConsumer
@@ -163,4 +169,4 @@ class IdeAutoCompleteHelper(LoggerMixin):
         self.publisher = consuming_func_decorated.publisher  # type: AbstractPublisher
         self.publish = self.pub = self.publisher.publish
         self.push = self.delay = self.publisher.push
-        self.clear = self.clear_queue = self.consumer.publisher_of_same_queue.clear = self.publisher.clear
+        self.clear = self.clear_queue = self.publisher.clear
